@@ -198,6 +198,12 @@ _set_zoom_items_sensitivity(GgvControl *control, BonoboUIComponent *uic, gboolea
 static void
 set_zoom_items_sensitivity(GgvControl *control, gboolean sens)
 {
+	Bonobo_UIContainer container;
+
+	container = bonobo_ui_component_get_container (control->priv->uic);
+	if (container == CORBA_OBJECT_NIL)
+		return;
+
 	bonobo_ui_component_set_prop(control->priv->uic,
 								 "/Sidebar/Zoom Control Placeholder/ZoomControl",
 								 "sensitive", sens?"1":"0", NULL);
@@ -898,8 +904,8 @@ ps_view_property_changed_handler(BonoboListener    *listener,
 {
         GgvControl *control = GGV_CONTROL(data);
 
-        if(!g_ascii_strcasecmp(event_name, "Bonobo/Property:change:page")) {
-			set_command_items_sensitivity(control, BONOBO_ARG_GET_INT(any) != -1);
+        if(!g_ascii_strcasecmp(event_name, "Bonobo/Property:change:page_count")) {
+			set_command_items_sensitivity(control, BONOBO_ARG_GET_LONG(any) > 0);
         }
 }
 
@@ -1011,18 +1017,12 @@ ggv_control_construct (GgvControl *control, GgvPostScriptView *ps_view)
 
 	bonobo_control_set_properties (BONOBO_CONTROL(control),
 								   BONOBO_OBJREF(property_bag), NULL);
-	mask = "Bonobo/Property:change:page";
+	mask = "Bonobo/Property:change:page_count";
 	bonobo_event_source_client_add_listener(BONOBO_OBJREF(property_bag),
 											(BonoboListenerCallbackFn)ps_view_property_changed_handler,
 											mask, NULL, control);
 	bonobo_object_unref (BONOBO_OBJECT (property_bag));
 
-	property_control =
-		ggv_postscript_view_get_property_control (control->priv->ps_view);
-	bonobo_object_add_interface (BONOBO_OBJECT (control),
-								 BONOBO_OBJECT (property_control));
-	bonobo_object_unref(BONOBO_OBJECT(property_control));
-
 	control->priv->uic =
 		bonobo_control_get_ui_component (BONOBO_CONTROL (control));
 
