@@ -41,6 +41,9 @@ ggv_recent_get_model (void)
 void
 ggv_recent_init (void)
 {
-	model = egg_recent_model_new ("ggv", EGG_RECENT_MODEL_SORT_MRU);
+	model = egg_recent_model_new (EGG_RECENT_MODEL_SORT_MRU);
 	egg_recent_model_set_limit(model, 5);
+	egg_recent_model_set_filter_mime_types(model,
+					       "application/postscript",
+					       NULL);
 }
