@@ -55,11 +55,6 @@ set_file_cmds_sensitivity(GgvWindow *win, gboolean sens)
                                      "sensitive",
                                      sens?"1":"0",
                                      NULL);
-        bonobo_ui_component_set_prop(win->uic,
-                                     "/commands/FileClose",
-                                     "sensitive",
-                                     sens?"1":"0",
-                                     NULL);
 }
 
 static void
@@ -140,14 +135,6 @@ ggv_window_remove_control(GgvWindow *win)
                 bonobo_object_release_unref(win->pb, NULL);
                 win->pb = CORBA_OBJECT_NIL;
         }
-#if 0
-        if(win->view) {
-                gtk_container_remove(GTK_CONTAINER(win->hbox),
-                                     win->view);
-                gtk_widget_unref(win->view);
-                win->view = NULL;
-        }
-#endif
         if(win->filename) {
                 g_free(win->filename);
                 win->filename = NULL;
@@ -262,7 +249,7 @@ ggv_window_drag_data_received(GtkWidget *widget,
                 GtkWidget *newwin;
                 gchar **uri = win->uris_to_open;
 
-                if(win->current_page < 0)
+                if(win->page_count <= 0)
                         newwin = GTK_WIDGET(win);
                 else
                         newwin = NULL;
@@ -270,14 +257,29 @@ ggv_window_drag_data_received(GtkWidget *widget,
 #ifdef _DEBUG
                         g_message("URI %s\n", *uri);
 #endif /* _DEBUG */
-                        if(newwin == NULL) {
+                        if(newwin == NULL)
                                 newwin = ggv_window_new();
-                                gtk_widget_show(newwin);
+                        if(ggv_window_load(GGV_WINDOW(newwin), (*uri))) {
+                                if(newwin != GTK_WIDGET(win))
+                                        gtk_widget_show(newwin);
+                                newwin = NULL;
+                        }
+                        else {
+                                GtkWidget *dlg;
+                                dlg = gtk_message_dialog_new(GTK_WINDOW(win),
+                                                             GTK_DIALOG_MODAL,
+                                                             GTK_MESSAGE_ERROR,
+                                                             GTK_BUTTONS_OK,
+                                                             _("Unable to load file:\n%s"),
+                                                             *uri);
+                                gtk_widget_show(dlg);
+                                gtk_dialog_run(GTK_DIALOG(dlg));
+                                gtk_widget_destroy(dlg);
                         }
-                        ggv_window_load(GGV_WINDOW(newwin), (*uri));
-                        newwin = NULL;
                         uri++;
                 }
+                if(newwin != NULL && newwin != GTK_WIDGET(win))
+                        ggv_window_close(GGV_WINDOW(newwin));
                 g_strfreev(win->uris_to_open);
                 win->uris_to_open = NULL;
         }
@@ -299,40 +301,16 @@ control_property_changed_handler(BonoboListener    *listener,
                                         BONOBO_ARG_GET_STRING(any));
         }
         else if(!g_ascii_strcasecmp(event_name, "Bonobo/Property:change:page")) {
-                if(win->current_page == BONOBO_ARG_GET_LONG(any) &&
-                   win->current_page < 0)
-                        return;
-
-                win->current_page = BONOBO_ARG_GET_LONG(any);
-                if(win->current_page < 0) {
-                        GtkWidget *dlg;
-                        BonoboArg *arg;
-                        gchar *msg;
-
-                        gtk_window_set_title(GTK_WINDOW(win),
-                                             _("GGV: no document loaded"));
-
-                        arg = bonobo_pbclient_get_value(win->pb, "status",
-                                                        NULL, NULL);
-                        if(arg == NULL)
-                                return;
-                        msg = BONOBO_ARG_GET_STRING(arg);
-                        if(*msg != '\0') {
-                                dlg = gtk_message_dialog_new(GTK_WINDOW(win),
-                                                             GTK_DIALOG_MODAL,
-                                                             GTK_MESSAGE_ERROR,
-                                                             GTK_BUTTONS_OK,
-                                                             msg);
-                                gtk_widget_show(dlg);
-                                gtk_dialog_run(GTK_DIALOG(dlg));
-                                gtk_widget_destroy(dlg);
-                        }
-                        bonobo_arg_release(arg);
-                        return;
-                }
+                if(win->current_page != BONOBO_ARG_GET_LONG(any))
+                        win->current_page = BONOBO_ARG_GET_LONG(any);
         }
         else if(!g_ascii_strcasecmp(event_name, "Bonobo/Property:change:page_count")) {
-                set_file_cmds_sensitivity(win, (BONOBO_ARG_GET_LONG(any) > 0));
+                win->page_count = BONOBO_ARG_GET_LONG(any);
+                set_file_cmds_sensitivity(win, win->page_count > 0);
+                if(win->page_count <= 0) {
+                        gtk_window_set_title(GTK_WINDOW(win),
+                                             _("GGV: no document loaded"));
+                }
         }
 }
 
@@ -341,10 +319,10 @@ verb_FileOpen(BonoboUIComponent *uic, gpointer data, const char *cname)
 {
         EggRecentItem *item;
         EggRecentModel *recent;
-
+        GSList *uris;
         GgvWindow *win = GGV_WINDOW(data);
-        gchar *fname = NULL, *escaped_fname;
 	GtkWidget *chooser;
+        GtkWidget *newwin;
 
 	chooser = gtk_file_chooser_dialog_new(_("Select a PostScript document"),
 					      GTK_WINDOW(win),
@@ -352,59 +330,79 @@ verb_FileOpen(BonoboUIComponent *uic, gpointer data, const char *cname)
 					      GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 					      GTK_STOCK_OPEN, GTK_RESPONSE_OK,
 					      NULL);
+        gtk_file_chooser_set_select_multiple(GTK_FILE_CHOOSER(chooser), TRUE);
 	gtk_dialog_set_default_response(GTK_DIALOG(chooser), GTK_RESPONSE_OK);
 	gtk_window_set_default_size(GTK_WINDOW(chooser), 600, 400);
+
+#if 0
+        /* this causes unexplained crashes! */
 	if (win->filename)
 		gtk_file_chooser_set_uri(GTK_FILE_CHOOSER(chooser),
 					 win->filename);
+#endif
 
-	if (gtk_dialog_run(GTK_DIALOG(chooser)) == GTK_RESPONSE_OK)
-		fname = gtk_file_chooser_get_uri(GTK_FILE_CHOOSER(chooser));
+        do {
+                uris = NULL;
+                if (gtk_dialog_run(GTK_DIALOG(chooser)) == GTK_RESPONSE_OK)
+                        uris = gtk_file_chooser_get_uris
+                                (GTK_FILE_CHOOSER(chooser));
+                else
+                        break;
+        } while(NULL == uris);
 
 	gtk_widget_destroy(chooser);
 
-        if(fname) {
-                if(!ggv_window_load(win, fname)) {
+        if(uris == NULL)
+                return;
+
+        if(win->page_count > 0)
+                newwin = NULL;
+        else
+                newwin = GTK_WIDGET(win);
+        while(uris) {
+                if(NULL == newwin)
+                        newwin = ggv_window_new();
+                if(!ggv_window_load(GGV_WINDOW(newwin),
+                                    (gchar *)uris->data)) {
                         GtkWidget *dlg;
-                        dlg = gtk_message_dialog_new(GTK_WINDOW(win),
-                                                     GTK_DIALOG_MODAL,
-                                                     GTK_MESSAGE_ERROR,
-                                                     GTK_BUTTONS_OK,
-                                                     _("Unable to load file:\n%s"),
-                                                     fname);
+                        dlg = gtk_message_dialog_new
+                                (GTK_WINDOW(win),
+                                 GTK_DIALOG_MODAL,
+                                 GTK_MESSAGE_ERROR,
+                                 GTK_BUTTONS_OK,
+                                 _("Unable to load file:\n%s"),
+                                 (gchar *)uris->data);
                         gtk_widget_show(dlg);
                         gtk_dialog_run(GTK_DIALOG(dlg));
                         gtk_widget_destroy(dlg);
                 }
-		recent = ggv_recent_get_model ();
-		item = egg_recent_item_new_from_uri (fname);
-		egg_recent_item_add_group (item, "ggv");
-		egg_recent_model_add_full (recent, item);
-		egg_recent_item_unref (item);
-
-                g_free(fname);
+                else {
+                        if(GTK_WIDGET(win) != newwin)
+                                gtk_widget_show(newwin);
+                        recent = ggv_recent_get_model ();
+                        item = egg_recent_item_new_from_uri
+                                ((gchar *)uris->data);
+                        egg_recent_item_set_mime_type
+                                (item, "application/postscript");
+                        egg_recent_item_add_group(item, "ggv");
+                        egg_recent_model_add_full (recent, item);
+                        egg_recent_item_unref (item);
+                        newwin = NULL;
+                }
+                g_free(uris->data);
+                uris = uris->next;
         }
+        if(NULL != newwin && GTK_WIDGET(win) != newwin)
+                ggv_window_close(GGV_WINDOW(newwin));
+        g_slist_free(uris);
 }
 
 static void
 verb_FileReload(BonoboUIComponent *uic, gpointer data, const char *cname)
 {
         GgvWindow *win = GGV_WINDOW(data);
-        GNOME_GGV_PostScriptView ps_view;
-        CORBA_Environment ev;
 
-        CORBA_exception_init(&ev);
-        ps_view = (GNOME_GGV_PostScriptView)
-                Bonobo_Unknown_queryInterface(win->control,
-                                              "IDL:GNOME/GGV/PostScriptView:1.0",
-                                              &ev);
-        if(!BONOBO_EX(&ev)) {
-                GNOME_GGV_PostScriptView_reload(ps_view, &ev);
-                if(BONOBO_EX(&ev))
-                        g_warning("Could not invoke reload method.");
-                bonobo_object_release_unref(ps_view, &ev);
-        }
-        CORBA_exception_free(&ev);
+        ggv_window_reload(win);
 }
 
 static void
@@ -412,49 +410,16 @@ verb_FileClose(BonoboUIComponent *uic, gpointer data, const char *cname)
 {
         GgvWindow *win = GGV_WINDOW(data);
 
-        if(window_list->next != NULL)
-                ggv_window_close(win);
-        else {
-                GNOME_GGV_PostScriptView ps_view;
-                CORBA_Environment ev;
-
-                CORBA_exception_init(&ev);
-                ps_view = (GNOME_GGV_PostScriptView)
-                        Bonobo_Unknown_queryInterface(win->control,
-                                                      "IDL:GNOME/GGV/PostScriptView:1.0",
-                                                      &ev);
-                if(!BONOBO_EX(&ev)) {
-                        GNOME_GGV_PostScriptView_close(ps_view, &ev);
-                        if(BONOBO_EX(&ev))
-                                g_warning("Could not invoke reload method.");
-                        bonobo_object_release_unref(ps_view, &ev);
-                }
-                CORBA_exception_free(&ev);                
-                ggv_window_set_watch_file(win, FALSE);
-        }
-}
-
-static void
-verb_FileNew(BonoboUIComponent *uic, gpointer data, const char *cname)
-{
-        GtkWidget *win = ggv_window_new();
-        gtk_widget_show(win);
+        ggv_window_close(win);
+        if (window_list == NULL)
+                bonobo_main_quit();
 }
 
 void
 ggv_window_destroy_all()
 {
         while(window_list)
-                gtk_widget_destroy(GTK_WIDGET(window_list->data));
-}
-
-static void
-verb_FileExit(BonoboUIComponent *uic, gpointer data, const char *cname)
-{
-        GList *l;
-
-        ggv_window_destroy_all();
-        bonobo_main_quit();
+                ggv_window_close(GGV_WINDOW(window_list->data));
 }
 
 static void
@@ -614,18 +579,35 @@ verb_DnDNewWindow(BonoboUIComponent *uic, gpointer user_data, const char *cname)
 {
         GgvWindow *win = GGV_WINDOW(user_data);
         gchar **uri;
-        GtkWidget *newwin;
+        GtkWidget *newwin = NULL;
 
         uri = win->uris_to_open;
         while(*uri && **uri != '\0') {
 #ifdef _DEBUG
                 g_message("URI %s", *uri);
 #endif /* _DEBUG */
-                newwin = ggv_window_new();
-                gtk_widget_show(newwin);
-                ggv_window_load(GGV_WINDOW(newwin), (*uri));
+                if(NULL == newwin)
+                        newwin = ggv_window_new();
+                if(ggv_window_load(GGV_WINDOW(newwin), (*uri))) {
+                        gtk_widget_show(newwin);
+                        newwin = NULL;
+                }
+                else {
+                        GtkWidget *dlg;
+                        dlg = gtk_message_dialog_new(GTK_WINDOW(win),
+                                                     GTK_DIALOG_MODAL,
+                                                     GTK_MESSAGE_ERROR,
+                                                     GTK_BUTTONS_OK,
+                                                     _("Unable to load file:\n%s"),
+                                                     *uri);
+                        gtk_widget_show(dlg);
+                        gtk_dialog_run(GTK_DIALOG(dlg));
+                        gtk_widget_destroy(dlg);
+                }
                 uri++;
         }
+        if(NULL != newwin)
+                ggv_window_close(GGV_WINDOW(newwin));
         g_strfreev(win->uris_to_open);
         win->uris_to_open = NULL;
 }
@@ -643,14 +625,29 @@ verb_DnDThisWindow(BonoboUIComponent *uic, gpointer user_data, const char *cname
 #ifdef _DEBUG
                 g_message("URI %s", *uri);
 #endif /* _DEBUG */
-                if(newwin == NULL) {
+                if(newwin == NULL)
                         newwin = ggv_window_new();
-                        gtk_widget_show(newwin);
+                if(ggv_window_load(GGV_WINDOW(newwin), (*uri))) {
+                        if(newwin != GTK_WIDGET(win))
+                                gtk_widget_show(newwin);
+                        newwin = NULL;
+                }
+                else {
+                        GtkWidget *dlg;
+                        dlg = gtk_message_dialog_new(GTK_WINDOW(win),
+                                                     GTK_DIALOG_MODAL,
+                                                     GTK_MESSAGE_ERROR,
+                                                     GTK_BUTTONS_OK,
+                                                     _("Unable to load file:\n%s"),
+                                                     *uri);
+                        gtk_widget_show(dlg);
+                        gtk_dialog_run(GTK_DIALOG(dlg));
+                        gtk_widget_destroy(dlg);
                 }
-                ggv_window_load(GGV_WINDOW(newwin), (*uri));
-                newwin = NULL;
                 uri++;
         }
+        if(NULL != newwin && newwin != GTK_WIDGET(win))
+                ggv_window_close(GGV_WINDOW(newwin));
         g_strfreev(win->uris_to_open);
         win->uris_to_open = NULL;	
 }
@@ -665,11 +662,9 @@ verb_DnDCancel(BonoboUIComponent *uic, gpointer user_data, const char *cname)
 
 /* our verb list */
 static BonoboUIVerb ggv_app_verbs[] = {
-        BONOBO_UI_VERB("FileNew", verb_FileNew),
         BONOBO_UI_VERB("FileClose", verb_FileClose),
         BONOBO_UI_VERB("FileOpen", verb_FileOpen),
         BONOBO_UI_VERB("FileReload", verb_FileReload),
-        BONOBO_UI_VERB("FileExit", verb_FileExit),
         BONOBO_UI_VERB("HelpAbout", verb_HelpAbout),
         BONOBO_UI_VERB("Help", verb_HelpContents),
         BONOBO_UI_VERB("DnDNewWindow", verb_DnDNewWindow),
@@ -695,7 +690,7 @@ static void
 ggv_window_destroy(GtkObject *object)
 {
         GgvWindow *win;
-        gint i;
+        gint i, w, h;
 
         g_return_if_fail(object != NULL);
         g_return_if_fail(GGV_IS_WINDOW(object));
@@ -733,8 +728,12 @@ ggv_window_destroy(GtkObject *object)
 
         window_list = g_list_remove(window_list, win);
 
-        ggv_get_window_size(GTK_WIDGET(object),
-                            &ggv_default_width, &ggv_default_height);
+        
+        ggv_get_window_size(GTK_WIDGET(object), &w, &h);
+        if(w > 1 && h > 1) {
+                ggv_default_width = w;
+                ggv_default_height = h;
+        }
 
         if(GTK_OBJECT_CLASS(parent_class)->destroy)
                 GTK_OBJECT_CLASS(parent_class)->destroy(object);
@@ -751,8 +750,9 @@ static void
 prefs_changed(GConfClient* client, guint cnxn_id,
               GConfEntry *entry, gpointer user_data)
 {
+        GgvWindow *window = GGV_WINDOW(user_data);
+
         if(!strcmp(entry->key, "/apps/ggv/layout/showtoolbar")) {
-                GgvWindow *window = GGV_WINDOW(user_data);
                 gboolean state_f = gconf_value_get_bool(entry->value);
                 if(window->show_toolbar != state_f) {
                         window->show_toolbar = state_f;
@@ -763,7 +763,6 @@ prefs_changed(GConfClient* client, guint cnxn_id,
                 }
         }
         else if(!strcmp(entry->key, "/apps/ggv/layout/showmenubar")) {
-                GgvWindow *window = GGV_WINDOW(user_data);
                 gboolean state_f = gconf_value_get_bool(entry->value);
                 if(window->show_menus != state_f) {
                         window->show_menus = state_f;
@@ -774,7 +773,6 @@ prefs_changed(GConfClient* client, guint cnxn_id,
                 }
         }
         else if(!strcmp(entry->key, "/apps/ggv/layout/showpanel")) {
-                GgvWindow *window = GGV_WINDOW(user_data);
                 gboolean state_f = gconf_value_get_bool(entry->value);
                 if(window->show_sidebar != state_f) {
                         window->show_sidebar = state_f;
@@ -785,7 +783,6 @@ prefs_changed(GConfClient* client, guint cnxn_id,
                 }
         }
         else if(!strcmp(entry->key, "/apps/ggv/layout/showstatusbar")) {
-                GgvWindow *window = GGV_WINDOW(user_data);
                 gboolean state_f = gconf_value_get_bool(entry->value);
                 if(window->show_statusbar != state_f) {
                         window->show_statusbar = state_f;
@@ -797,6 +794,12 @@ prefs_changed(GConfClient* client, guint cnxn_id,
                                 gtk_widget_hide(window->statusbar);
                 }
         }
+        else if(!strcmp(entry->key, "/apps/ggv/layout/rightpanel")) {
+#if 0
+                bonobo_control_frame_control_deactivate(window->ctlframe);
+                bonobo_control_frame_control_activate(window->ctlframe);
+#endif
+        }
 }
 
 static void
@@ -917,18 +920,31 @@ ggv_file_open_recent (EggRecentView *view, EggRecentItem *item, gpointer data)
                                                                                                                              
         uri_utf8 = egg_recent_item_get_uri_utf8 (item);
                                                                                                                              
-        if(win->current_page < 0)
+        if(win->page_count <= 0)
                 newwin = GTK_WIDGET (win);
-        else
-                newwin = NULL;
-                                                                                                                             
-        if (newwin == NULL) {
+        else {
                 newwin = ggv_window_new ();
-                gtk_widget_show (GTK_WIDGET (newwin));
         }
                                                                                                                              
-        ggv_window_load (GGV_WINDOW (newwin), uri_utf8);
-        newwin = NULL;
+        if(ggv_window_load (GGV_WINDOW (newwin), uri_utf8)) {
+                if(newwin != GTK_WIDGET(win))
+                        gtk_widget_show(newwin);
+        }
+        else {
+                GtkWidget *dlg;
+                dlg = gtk_message_dialog_new(GTK_WINDOW(win),
+                                             GTK_DIALOG_MODAL,
+                                             GTK_MESSAGE_ERROR,
+                                             GTK_BUTTONS_OK,
+                                             _("Unable to load file:\n%s"),
+                                             uri_utf8);
+                gtk_widget_show(dlg);
+                gtk_dialog_run(GTK_DIALOG(dlg));
+                gtk_widget_destroy(dlg);
+                if(newwin != GTK_WIDGET(win))
+                        ggv_window_close(GGV_WINDOW(newwin));
+        }
+
                                                                                                                              
         return TRUE;
 }
@@ -948,7 +964,7 @@ ggv_add_open_button (GgvWindow *win, BonoboUIComponent *ui_component,
                            gtk_arrow_new (GTK_ARROW_DOWN, GTK_SHADOW_OUT));
                                                                                                                              
         gtk_widget_show_all (GTK_WIDGET (button));
-                                                                                                                             
+
         model = ggv_recent_get_model ();
                                                                                                                              
         menu = gtk_menu_new ();
@@ -1003,7 +1019,7 @@ ggv_window_new(void)
 	win = GGV_WINDOW(g_object_new(GGV_TYPE_WINDOW, "win_name", "ggv", "title", _("GGV: no document loaded"), NULL));
         win->control = control;
 
-        win->current_page = -2;
+        win->current_page = 0;
         win->show_toolbar = ggv_toolbar;
         win->show_menus = ggv_menubar;
         win->show_statusbar = ggv_statusbar;
@@ -1100,16 +1116,6 @@ ggv_window_new(void)
                         "Bonobo/Property:change:height,"
                         "Bonobo/Property:change:title,"
                         "Bonobo/Property:change:status";
-                bonobo_ui_component_set_prop(win->uic,
-                                             "/commands/FileReload",
-                                             "sensitive",
-                                             (bonobo_pbclient_get_long(pb, "page", NULL) >= 0)?"1":"0",
-                                             NULL);
-                bonobo_ui_component_set_prop(win->uic,
-                                             "/commands/FileClose",
-                                             "sensitive",
-                                             (bonobo_pbclient_get_long(pb, "page", NULL) >= 0)?"1":"0",
-                                             NULL);
                 bonobo_event_source_client_add_listener(pb,
                                                         (BonoboListenerCallbackFn)control_property_changed_handler,
                                                         mask, NULL, win);
@@ -1148,6 +1154,8 @@ ggv_window_new(void)
                                 (GConfClientNotifyFunc)prefs_changed,
                                 win, NULL, NULL);
 
+        set_file_cmds_sensitivity(win, FALSE);
+
 	return GTK_WIDGET(win);
 }
 
@@ -1156,8 +1164,9 @@ ggv_window_load(GgvWindow *win, const gchar *filename)
 {
         CORBA_Environment ev;
         Bonobo_PersistFile pf;
-        gchar *title, *unescaped, *utf8_title;
+        gchar *title, *unescaped, *utf8_title, *_filename;
         GnomeVFSFileInfo info;
+	Bonobo_UIContainer container;
 
         g_return_val_if_fail(win != NULL, FALSE);
         g_return_val_if_fail(GGV_IS_WINDOW(win), FALSE);
@@ -1170,23 +1179,37 @@ ggv_window_load(GgvWindow *win, const gchar *filename)
                                                     GNOME_VFS_FILE_INFO_FOLLOW_LINKS)) {
                 win->mtime = info.mtime;
         }
-        else
+        else {
+                GNOME_GGV_PostScriptView view;
+
+                CORBA_exception_init(&ev);
+                view = Bonobo_Unknown_queryInterface
+                        (win->control, "IDL:GNOME/GGV/PostScriptView:1.0",
+                         &ev);
+                if(!BONOBO_EX(&ev) && view != CORBA_OBJECT_NIL) {
+                        GNOME_GGV_PostScriptView_close(view, &ev);
+                }
+                CORBA_exception_free(&ev);
+                ggv_window_set_watch_file(win, ggv_watch_doc);
                 return FALSE;
+        }
 
         CORBA_exception_init(&ev);
         pf = Bonobo_Unknown_queryInterface(win->control,
                                            "IDL:Bonobo/PersistFile:1.0", &ev);
         if(BONOBO_EX(&ev) || pf == CORBA_OBJECT_NIL) {
                 CORBA_exception_free(&ev);
+                ggv_window_set_watch_file(win, ggv_watch_doc);
                 return FALSE;
         }
 
         Bonobo_PersistFile_load(pf, filename, &ev);
         bonobo_object_release_unref(pf, NULL);
 
+        _filename = g_strdup(filename);
         if(win->filename)
                 g_free(win->filename);
-        win->filename = g_strdup(filename);
+        win->filename = _filename;
 
         unescaped = gnome_vfs_unescape_string_for_display(win->filename);
         title = g_strconcat(_("GGV: "), unescaped, NULL);
@@ -1198,18 +1221,18 @@ ggv_window_load(GgvWindow *win, const gchar *filename)
 
         if(BONOBO_EX(&ev)) {
                 CORBA_exception_free(&ev);
+                ggv_window_set_watch_file(win, ggv_watch_doc);
                 return FALSE;
         }
         CORBA_exception_free(&ev);
 
-        bonobo_ui_component_set_prop
-                (win->uic, "/commands/FileReload", "sensitive",
-                 (bonobo_pbclient_get_long(win->pb, "page", NULL) >= 0)?"1":"0",
-                 NULL);
-        bonobo_ui_component_set_prop
-                (win->uic, "/commands/FileClose", "sensitive",
-                 (bonobo_pbclient_get_long(win->pb, "page", NULL) >= 0)?"1":"0",
-                 NULL);
+        win->page_count = bonobo_pbclient_get_long(win->pb, "page_count", NULL);
+
+	container = bonobo_ui_component_get_container (win->uic);
+	if (container != CORBA_OBJECT_NIL)
+                bonobo_ui_component_set_prop
+                        (win->uic, "/commands/FileReload", "sensitive",
+                         (win->page_count > 0)?"1":"0", NULL);
 
         ggv_window_set_watch_file(win, ggv_watch_doc);
 
@@ -1222,6 +1245,8 @@ ggv_window_close(GgvWindow *win)
         g_return_if_fail(win != NULL);
         g_return_if_fail(GGV_IS_WINDOW(win));
 
+        bonobo_control_frame_control_deactivate(win->ctlframe);
+
         gtk_widget_destroy(GTK_WIDGET(win));
 
         if(!window_list)
@@ -1234,6 +1259,25 @@ ggv_get_window_list()
         return window_list;
 }
 
+void
+ggv_window_reload(GgvWindow *win)
+{
+        gint page = win->current_page;  
+        if(!ggv_window_load(win, win->filename)) {
+                GtkWidget *dlg;
+                dlg = gtk_message_dialog_new(GTK_WINDOW(win),
+                                             GTK_DIALOG_MODAL,
+                                             GTK_MESSAGE_ERROR,
+                                             GTK_BUTTONS_OK,
+                                             _("Unable to load file:\n%s"),
+                                             win->filename);
+                gtk_widget_show(dlg);
+                gtk_dialog_run(GTK_DIALOG(dlg));
+                gtk_widget_destroy(dlg);
+        }
+        bonobo_pbclient_set_long(win->pb, "page", page, NULL);
+}
+
 /* Reload file if it was changed */
 static gint
 timer_callback (gpointer data)
@@ -1257,25 +1301,12 @@ timer_callback (gpointer data)
                 return TRUE;
 
         /* reload file if necessary */
-	if ((win->current_page >= 0) &&
-	    (info.mtime != win->mtime) &&
+	if ((info.mtime != win->mtime) &&
 	    (time (NULL) - info.mtime >= GGV_WATCH_TIMEOUT) &&
             (NULL != win->control)) {
-                GNOME_GGV_PostScriptView ps_view;
-                CORBA_Environment ev;
-
-                CORBA_exception_init(&ev);
-                ps_view = (GNOME_GGV_PostScriptView)
-                        Bonobo_Unknown_queryInterface(win->control,
-                                                      "IDL:GNOME/GGV/PostScriptView:1.0",
-                                                      &ev);
-                if(!BONOBO_EX(&ev)) {
-                        GNOME_GGV_PostScriptView_reload(ps_view, &ev);
-                        if(BONOBO_EX(&ev))
-                                g_warning("Could not invoke reload method.");
-                        bonobo_object_release_unref(ps_view, &ev);
-                }
-                CORBA_exception_free(&ev);
+                gint page = win->current_page;  
+                ggv_window_load(win, win->filename);
+                bonobo_pbclient_set_long(win->pb, "page", page, NULL);
                 win->mtime = info.mtime;
         }
 
