@@ -543,7 +543,7 @@ gtk_gs_munge_adjustments (GtkGS *gs)
 			x = gs->widget.allocation.width - gs->width;
 		gs->hadj->page_size = ((gfloat) gs->widget.allocation.width)/gs->width;
                 gs->hadj->page_increment = gs->hadj->page_size*0.9;
-                gs->hadj->step_increment = 1.0/gs->width;
+                gs->hadj->step_increment = gs->scroll_step*gs->hadj->page_size;
 		gs->hadj->value = -((gfloat)x)/gs->width;
 	}
 	if (gs->widget.allocation.height >= gs->height ||
@@ -560,7 +560,7 @@ gtk_gs_munge_adjustments (GtkGS *gs)
 			y = gs->widget.allocation.height - gs->height;
 		gs->vadj->page_size = ((gfloat) gs->widget.allocation.height)/gs->height;
                 gs->vadj->page_increment = gs->vadj->page_size*0.9;
-                gs->vadj->step_increment = 1.0/gs->height;
+                gs->vadj->step_increment = gs->scroll_step*gs->vadj->page_size;
 		gs->vadj->value = -((gfloat)y)/gs->height;
 	}
 
@@ -818,7 +818,7 @@ set_up_page (GtkGS *gs)
         stop_interpreter(gs);
         
         orientation = gtk_gs_get_orientation(gs);
-        
+
         if (compute_size (gs)) {
                 gdk_flush();
 
@@ -887,7 +887,6 @@ set_up_page (GtkGS *gs)
                             GDK_PROP_MODE_REPLACE,
                             buf,
                             strlen(buf));
-
         gdk_flush();
 }
 
@@ -975,7 +974,7 @@ input (gpointer data, gint source, GdkInputCondition condition)
                         if (gs->ps_input && gs->bytes_left == 0) {
                                 struct record_list *ps_old = gs->ps_input;
                                 gs->ps_input = ps_old->next;
-                                if (ps_old->close) 
+                                if (ps_old->close && NULL != ps_old->fp) 
                                         fclose(ps_old->fp);
                                 g_free((char *)ps_old);
                         }
@@ -1222,7 +1221,7 @@ stop_interpreter (GtkGS *gs)
                 while (gs->ps_input) {
                         struct record_list *ps_old = gs->ps_input;
                         gs->ps_input = gs->ps_input->next;
-                        if (ps_old->close)
+                        if (ps_old->close && NULL != ps_old->fp)
                                 fclose (ps_old->fp);
                         g_free ((char *)ps_old);
                 }
@@ -1440,7 +1439,8 @@ check_pdf (GtkGS *gs)
 		g_free (filename_err);
 		g_free (cmdline);
 	}
-	fclose (file);
+        if(NULL != file)
+                fclose (file);
 	return filename;
 }
 
@@ -1768,11 +1768,10 @@ gtk_gs_load (GtkGS *gs, const gchar *fname)
 		}
 
                 /* we grab the vital statistics!!! */
-		gs->doc = psscan(gs->gs_psfile, gs->respect_eof);
+		gs->doc = psscan(gs->gs_psfile, gs->respect_eof, fname);
 
                 if (gs->doc == NULL) {
                         /* File does not seem to be a Postscript one */
-                        /* We have to report error to the reader, do we do it here */
 			gchar buf[1024];
 			g_snprintf (buf, 1024,
 				    _("Error while scanning file %s\n"), fname);
@@ -2592,11 +2591,13 @@ gtk_gs_get_postscript(GtkGS *gs, gint *pages)
                         if(!doc)
                                 return NULL;
                         f = fopen(GTK_GS_GET_PS_FILE(gs), "r");
-                        if(fread(doc, sb.st_size, 1, f) != 1) {
+                        if(NULL != f &&
+                           fread(doc, sb.st_size, 1, f) != 1) {
                                 g_free(doc);
                                 doc = NULL;
                         }
-                        fclose(f);
+                        if(NULL != f)
+                                fclose(f);
                         return doc;
                 }
                 else {
