@@ -51,17 +51,22 @@ create_window(const gchar *filename)
         }
 
         if(filename)
-                ggv_window_load(win, filename);
+                if(!ggv_window_load(win, filename)) {
+                        ggv_window_close(win);
+                        win = NULL;
+                }
 
-        if(win_geometry) {
-                if(!gtk_window_parse_geometry(GTK_WINDOW(win), win_geometry))
-                        g_warning(_("Invalid geometry string \"%s\"\n"),
-                                  win_geometry);
-                win_geometry = NULL;
+        if(NULL != win) {
+                if(win_geometry) {
+                        if(!gtk_window_parse_geometry(GTK_WINDOW(win), win_geometry))
+                                g_warning(_("Invalid geometry string \"%s\"\n"),
+                                          win_geometry);
+                        win_geometry = NULL;
+                }
+                
+                gtk_widget_show(GTK_WIDGET(win));
         }
 
-        gtk_widget_show(GTK_WIDGET(win));
-
         return win;
 }
 
